@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.in_interfaces.camera import Camera
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Cameras(Collection):
@@ -142,5 +143,9 @@ class Cameras(Collection):
 
         return Camera(self.cameras.item(n + 1))
 
+    def __iter__(self) -> Iterator[Camera]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Cameras(name="{self.name}")'
