@@ -16,6 +16,8 @@ class MacrosSettingAtt(SettingController):
 
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
 
                 | System.IUnknown
@@ -37,6 +39,8 @@ class MacrosSettingAtt(SettingController):
     def get_default_macro_libraries(self) -> tuple:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDefaultMacroLibraries() As CATSafeArrayVariant
                 | 
@@ -50,6 +54,8 @@ class MacrosSettingAtt(SettingController):
     def get_default_macro_libraries_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDefaultMacroLibrariesInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
@@ -84,6 +90,8 @@ class MacrosSettingAtt(SettingController):
     def get_external_references(self) -> tuple:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetExternalReferences() As CATSafeArrayVariant
                 | 
@@ -97,6 +105,8 @@ class MacrosSettingAtt(SettingController):
     def get_external_references_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetExternalReferencesInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
@@ -131,6 +141,8 @@ class MacrosSettingAtt(SettingController):
     def get_language_editor(self, i_language: int) -> str:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLanguageEditor(CATScriptLanguage iLanguage) As
                 | CATBSTR
@@ -146,6 +158,8 @@ class MacrosSettingAtt(SettingController):
     def get_language_editor_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLanguageEditorInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
@@ -180,6 +194,8 @@ class MacrosSettingAtt(SettingController):
     def set_default_macro_libraries(self, i_libraries: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDefaultMacroLibraries(CATSafeArrayVariant
                 | iLibraries)
@@ -204,12 +220,14 @@ class MacrosSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_default_macro_libraries_lock(self, i_locked: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDefaultMacroLibrariesLock(boolean iLocked)
                 | 
@@ -244,12 +262,14 @@ class MacrosSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_external_references(self, i_references: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetExternalReferences(CATSafeArrayVariant iReferences)
                 | 
@@ -273,12 +293,14 @@ class MacrosSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_external_references_lock(self, i_locked: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetExternalReferencesLock(boolean iLocked)
                 | 
@@ -313,12 +335,14 @@ class MacrosSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_language_editor(self, i_language: int, i_editor_path: str) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLanguageEditor(CATScriptLanguage iLanguage,
                 | CATBSTR iEditorPath)
@@ -335,6 +359,8 @@ class MacrosSettingAtt(SettingController):
     def set_language_editor_lock(self, i_locked: bool) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLanguageEditorLock(boolean iLocked)
                 | 
@@ -369,7 +395,7 @@ class MacrosSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
