@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.knowledge_interfaces.unit import Unit
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Units(Collection):
@@ -78,5 +79,9 @@ class Units(Collection):
 
         return Unit(self.units.item(n + 1))
 
+    def __iter__(self) -> Iterator[Unit]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Units(name="{self.name}")'
