@@ -11,7 +11,7 @@
 
 from pycatia.product_structure_interfaces.product import Product
 from pycatia.system_interfaces.any_object import AnyObject
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class FixTogether(AnyObject):
