@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.mec_mod_interfaces.fix_together import FixTogether
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class FixTogethers(Collection):
@@ -140,5 +141,9 @@ class FixTogethers(Collection):
 
         return FixTogether(self.fix_togethers.item(n + 1))
 
+    def __iter__(self) -> Iterator[FixTogether]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'FixTogethers(name="{self.name}")'
