@@ -29,6 +29,7 @@ from pycatia.part_interfaces.shape_factory import ShapeFactory
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.product_structure_interfaces.analyze import Analyze
 from pycatia.system_interfaces.collection import Collection
+from pycatia.tps_interfaces.annotation_sets import AnnotationSets
 
 
 class Part(AnyObject):
@@ -114,7 +115,7 @@ class Part(AnyObject):
         :return: Collection
         """
 
-        return Collection(self.part.AnnotationSets)
+        return AnnotationSets(self.part.AnnotationSets)
 
     @property
     def axis_systems(self) -> AxisSystems:
