@@ -8,11 +8,12 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.mec_mod_interfaces.boundary import Boundary
 from pycatia.mec_mod_interfaces.shape import Shape
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Shapes(Collection):
@@ -105,5 +106,9 @@ class Shapes(Collection):
 
         return Shape(self.shapes.item(n + 1))
 
+    def __iter__(self) -> Iterator[Shape]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Shapes(name="{self.name}")'
