@@ -8,11 +8,13 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.in_interfaces.reference import Reference
 from pycatia.mec_mod_interfaces.boundary import Boundary
 from pycatia.sketcher_interfaces.sketch import Sketch
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Sketches(Collection):
@@ -138,5 +140,9 @@ class Sketches(Collection):
 
         return Sketch(self.sketches.item(n + 1))
 
+    def __iter__(self) -> Iterator[Sketch]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Sketches(name="{self.name}")'
