@@ -8,11 +8,13 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.navigator_interfaces.dmu_review import DMUReview
 from pycatia.product_structure_interfaces.product import Product
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class DMUReviews(Collection):
@@ -208,5 +210,9 @@ class DMUReviews(Collection):
 
         return DMUReview(self.dmu_reviews.item(n + 1))
 
+    def __iter__(self) -> Iterator[DMUReview]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'DmuReviews(name="{self.name}")'
