@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.navigator_interfaces.group import Group
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Groups(Collection):
@@ -201,5 +203,9 @@ class Groups(Collection):
 
         return Group(self.groups.item(n + 1))
 
+    def __iter__(self) -> Iterator[Group]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Groups(name="{self.name}")'
