@@ -13,6 +13,9 @@ from pathlib import Path
 from typing import TYPE_CHECKING
 import warnings
 
+from pywintypes import com_error
+
+from pycatia.exception_handling.exceptions import CATIAApplicationException
 from pycatia.in_interfaces.move import Move
 from pycatia.in_interfaces.position import Position
 from pycatia.in_interfaces.reference import Reference
@@ -205,7 +208,7 @@ class Product(AnyObject):
         :return: str()
         """
 
-        return self.product.ReferenceProduct.Parent.Name
+        return self.reference_product.parent.name
 
     @property
     def full_name(self):
@@ -213,7 +216,7 @@ class Product(AnyObject):
         :return: str()
         """
 
-        return self.product.ReferenceProduct.Parent.FullName
+        return self.reference_product.parent.com_object.FullName
 
     @property
     def move(self):
@@ -329,8 +332,10 @@ class Product(AnyObject):
         :return: str
         :rtype: str
         """
-
-        return self.product.PartNumber
+        try:
+            return self.product.PartNumber
+        except com_error:
+            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Product.PartNumber. Check Product for broken links.')
 
     @part_number.setter
     def part_number(self, value: str):
@@ -338,7 +343,10 @@ class Product(AnyObject):
         :param str value:
         """
 
-        self.product.PartNumber = value
+        try:
+            self.product.PartNumber = value
+        except com_error:
+            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do set Product.PartNumber. Check Product for broken links.')
 
     @property
     def position(self) -> Position:
@@ -427,8 +435,10 @@ class Product(AnyObject):
         :return: Product
         :rtype: Product
         """
-
-        return Product(self.product.ReferenceProduct)
+        try:
+            return Product(self.product.ReferenceProduct)
+        except com_error:
+            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Reference Product. Check Product for broken links.')
 
     @property
     def relations(self) -> Relations:
@@ -519,7 +529,10 @@ class Product(AnyObject):
         :rtype: int
         """
 
-        return self.product.Source
+        try:
+            return self.product.Source
+        except com_error:
+            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Product.Source. Check Product for broken links.')
 
     @source.setter
     def source(self, value: int):
@@ -527,7 +540,26 @@ class Product(AnyObject):
         :param int value:
         """
 
-        self.product.Source = value
+        try:
+            self.product.Source = value
+        except com_error:
+            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do set Product.Source. Check Product for broken links.')
+
+    @property
+    def type(self) -> str:
+        """
+        Returns the type of product (CATProduct, CATPart or Component).
+
+        :return: str
+        :rtype: str
+        """
+        
+        root_product_name = self.reference_product.com_object.Parent.Product.Name
+        self_product_name = self.reference_product.name
+        if root_product_name == self_product_name:
+            return self.reference_product.com_object.Parent.Name.split('.')[-1]
+        else:
+            return "Component"
 
     @property
     def user_ref_properties(self) -> Parameters:
