@@ -8,12 +8,12 @@
         and thus help debugging in pycatia.
 
 """
-
+from typing import Iterator
 from typing import TYPE_CHECKING
 
 from pycatia.product_structure_interfaces.product import Product
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 if TYPE_CHECKING:
     from pycatia.in_interfaces.document import Document
@@ -405,5 +405,9 @@ class Products(Collection):
 
         return Product(self.products.item(n + 1))
 
+    def __iter__(self) -> Iterator[Product]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Products(name="{self.name}")'
