@@ -487,7 +487,7 @@ class Measurable(AnyObject):
             |   TheMeasurable.GetMinimumDistancePoints reference2, Coordinates
 
         :param i_measured_item:
-        :return: tuple(float, float, float, float, float, float, float, float)
+        :return: tuple(float, float, float, float, float, float, float, float, float)
         """
 
         vba_function_name = 'get_minimum_distance_points'
@@ -670,4 +670,4 @@ class Measurable(AnyObject):
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
     def __repr__(self):
-        return f'CATIAMeasurable()'
+        return f'CATIAMeasurable({self.name})'
